---
name: Bug report
about: Create a report to help us improve
title: "[BUG]"
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.


**To Reproduce**
Steps to reproduce the behavior:


**Expected behavior**
A clear and concise description of what you expected to happen.


**Screenshots**
If applicable, add screenshots to help explain your problem.


**Extra info:**
 - OS: [e.g. Amazon Linux 2]
 - Affected Version
